// Copyright 2024 The Khronos Group
// SPDX-License-Identifier: Apache-2.0

#pragma once

#include <pxr/base/tf/debug.h>
#include <pxr/base/tf/preprocessorUtilsLite.h>
#include <pxr/pxr.h>

PXR_NAMESPACE_OPEN_SCOPE

// clang-format off
TF_DEBUG_CODES(
    HD_ANARI_RD_GEOMETRY,
    HD_ANARI_RD_INSTANCER,
    HD_ANARI_RD_MATERIAL,
    HD_ANARI_RD_MESH,
    HD_ANARI_RD_POINTS,
    HD_ANARI_RD_RENDERDELEGATE,
    HD_ANARI_RD_RENDERPARAMS,
    HD_ANARI_RD_RENDERPASS
);
//clang-format on

PXR_NAMESPACE_CLOSE_SCOPE
